14.35. cdist-type__docker(7) — cdist 4.8.1 documentation

# 14.35. cdist-type__docker(7)

## 14.35.1. NAME

cdist-type__docker - install docker-engine

## 14.35.2. DESCRIPTION

Installs latest docker-engine package from dockerproject.org.

## 14.35.3. REQUIRED PARAMETERS

None.

## 14.35.4. OPTIONAL PARAMETERS

None.

## 14.35.5. BOOLEAN PARAMETERS

experimental
  Install the experimental docker-engine package instead of the latest stable release.
state
  'present' or 'absent', defaults to 'present'

## 14.35.6. EXAMPLES

    # Install docker
    __docker

    # Install experimental
    __docker --experimental

    # Remove docker
    __docker --state absent

## 14.35.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 14.35.8. COPYING

Copyright (C) 2016 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).